# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_gcmessages_common_match_management.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.steammessages_pb2 as steammessages__pb2
import dota2.protobufs.gcsdk_gcmessages_pb2 as gcsdk__gcmessages__pb2
import dota2.protobufs.dota_shared_enums_pb2 as dota__shared__enums__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_gcmessages_common_match_management.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n-dota_gcmessages_common_match_management.proto\x1a\x13steammessages.proto\x1a\x16gcsdk_gcmessages.proto\x1a\x17\x64ota_shared_enums.proto\"\x94\x02\n\x12\x43SODOTAPartyMember\x12\x37\n\x0cpartner_type\x18\x01 \x01(\x0e\x32\x13.PartnerAccountType:\x0cPARTNER_NONE\x12\x10\n\x08is_coach\x18\x02 \x01(\x08\x12\x1d\n\x11region_ping_codes\x18\x04 \x03(\rB\x02\x10\x01\x12\x1d\n\x11region_ping_times\x18\x05 \x03(\rB\x02\x10\x01\x12\"\n\x1aregion_ping_failed_bitmask\x18\x06 \x01(\r\x12\x1b\n\x13tourney_skill_level\x18\x07 \x01(\r\x12\x15\n\rtourney_buyin\x18\x08 \x01(\r\x12\x1d\n\x15tourney_prevent_until\x18\t \x01(\r\"\xb6\x0b\n\x0c\x43SODOTAParty\x12\x16\n\x08party_id\x18\x01 \x01(\x04\x42\x04\x80\x97\"\x01\x12\x11\n\tleader_id\x18\x02 \x01(\x06\x12\x12\n\nmember_ids\x18\x03 \x03(\x06\x12\x12\n\ngame_modes\x18\x04 \x01(\r\x12&\n\x05state\x18\x06 \x01(\x0e\x32\x13.CSODOTAParty.State:\x02UI\x12*\n\"effective_started_matchmaking_time\x18\x07 \x01(\r\x12$\n\x1craw_started_matchmaking_time\x18  \x01(\r\x12\x1a\n\x12\x61ttempt_start_time\x18! \x01(\r\x12\x13\n\x0b\x61ttempt_num\x18\" \x01(\r\x12\x13\n\x0bmatchgroups\x18\x0b \x01(\r\x12\x1f\n\x17low_priority_account_id\x18\x13 \x01(\r\x12\x31\n\nmatch_type\x18\x15 \x01(\x0e\x32\n.MatchType:\x11MATCH_TYPE_CASUAL\x12\x42\n\x0e\x62ot_difficulty\x18\x16 \x01(\x0e\x32\x12.DOTABotDifficulty:\x16\x42OT_DIFFICULTY_PASSIVE\x12\x0f\n\x07team_id\x18\x17 \x01(\r\x12\x11\n\tteam_name\x18\x33 \x01(\t\x12\x14\n\x0cteam_ui_logo\x18\x34 \x01(\x04\x12\x16\n\x0eteam_base_logo\x18\x35 \x01(\x04\x12!\n\x19match_disabled_until_date\x18\x18 \x01(\r\x12!\n\x19match_disabled_account_id\x18\x19 \x01(\r\x12%\n\x1dmatchmaking_max_range_minutes\x18\x1a \x01(\r\x12\x16\n\x0ematchlanguages\x18\x1b \x01(\r\x12\x16\n\x0emap_preference\x18& \x01(\r\x12$\n\x07members\x18\x1d \x03(\x0b\x32\x13.CSODOTAPartyMember\x12\x15\n\ropen_guild_id\x18\x1e \x01(\r\x12\x15\n\rcommon_guilds\x18\x1f \x03(\r\x12$\n\x1clow_priority_games_remaining\x18# \x01(\r\x12%\n\x14\x61\x63tive_ingame_events\x18\' \x03(\x0e\x32\x07.EEvent\x12\x1e\n\x16open_for_join_requests\x18( \x01(\x08\x12)\n\x0csent_invites\x18) \x03(\x0b\x32\x13.CSODOTAPartyInvite\x12)\n\x0crecv_invites\x18* \x03(\x0b\x32\x13.CSODOTAPartyInvite\x12\x15\n\raccount_flags\x18+ \x01(\r\x12\x1b\n\x13region_select_flags\x18, \x01(\r\x12\x1f\n\x17\x65xclusive_tournament_id\x18- \x01(\r\x12\x1b\n\x13tourney_division_id\x18/ \x01(\r\x12\x1d\n\x15tourney_schedule_time\x18\x30 \x01(\r\x12\x1b\n\x13tourney_skill_level\x18\x31 \x01(\r\x12\x1d\n\x15tourney_bracket_round\x18\x32 \x01(\r\x12#\n\x1btourney_queue_deadline_time\x18\x36 \x01(\r\x12\x66\n\x1ctourney_queue_deadline_state\x18\x37 \x01(\x0e\x32\x1b.ETourneyQueueDeadlineState:#k_ETourneyQueueDeadlineState_Normal\x12#\n\x1bparty_builder_slots_to_fill\x18\x38 \x01(\r\x12\"\n\x1aparty_builder_match_groups\x18\x39 \x01(\r\x12 \n\x18party_builder_start_time\x18: \x01(\r\"0\n\x05State\x12\x06\n\x02UI\x10\x00\x12\x11\n\rFINDING_MATCH\x10\x01\x12\x0c\n\x08IN_MATCH\x10\x02\"\x9b\x02\n\x12\x43SODOTAPartyInvite\x12\x16\n\x08group_id\x18\x01 \x01(\x04\x42\x04\x80\x97\"\x01\x12\x11\n\tsender_id\x18\x02 \x01(\x06\x12\x13\n\x0bsender_name\x18\x03 \x01(\t\x12\x30\n\x07members\x18\x04 \x03(\x0b\x32\x1f.CSODOTAPartyInvite.PartyMember\x12\x0f\n\x07team_id\x18\x05 \x01(\r\x12\x1b\n\x13low_priority_status\x18\x06 \x01(\x08\x12\x10\n\x08\x61s_coach\x18\x07 \x01(\x08\x12\x12\n\ninvite_gid\x18\x08 \x01(\x06\x1a?\n\x0bPartyMember\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08steam_id\x18\x02 \x01(\x06\x12\x10\n\x08is_coach\x18\x04 \x01(\x08\"\x99\x02\n\x12\x43SODOTALobbyInvite\x12\x16\n\x08group_id\x18\x01 \x01(\x04\x42\x04\x80\x97\"\x01\x12\x11\n\tsender_id\x18\x02 \x01(\x06\x12\x13\n\x0bsender_name\x18\x03 \x01(\t\x12\x30\n\x07members\x18\x04 \x03(\x0b\x32\x1f.CSODOTALobbyInvite.LobbyMember\x12\x16\n\x0e\x63ustom_game_id\x18\x05 \x01(\x04\x12\x12\n\ninvite_gid\x18\x06 \x01(\x06\x12\x17\n\x0f\x63ustom_game_crc\x18\x07 \x01(\x06\x12\x1d\n\x15\x63ustom_game_timestamp\x18\x08 \x01(\x07\x1a-\n\x0bLobbyMember\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08steam_id\x18\x02 \x01(\x06\"\xd5\x01\n\x0f\x43MsgLeaverState\x12\x13\n\x0blobby_state\x18\x01 \x01(\r\x12>\n\ngame_state\x18\x02 \x01(\x0e\x32\x0f.DOTA_GameState:\x19\x44OTA_GAMERULES_STATE_INIT\x12\x17\n\x0fleaver_detected\x18\x03 \x01(\x08\x12\x1c\n\x14\x66irst_blood_happened\x18\x04 \x01(\x08\x12\x1d\n\x15\x64iscard_match_results\x18\x05 \x01(\x08\x12\x17\n\x0fmass_disconnect\x18\x06 \x01(\x08\"\x8f\x07\n\x10\x43\x44OTALobbyMember\x12\x10\n\x02id\x18\x01 \x01(\x06\x42\x04\x80\x97\"\x01\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x33\n\x04team\x18\x03 \x01(\x0e\x32\r.DOTA_GC_TEAM:\x16\x44OTA_GC_TEAM_GOOD_GUYS\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0c\n\x04slot\x18\x07 \x01(\r\x12\x10\n\x08party_id\x18\x0c \x01(\x04\x12\x12\n\nmeta_level\x18\r \x01(\r\x12\x0f\n\x07meta_xp\x18\x0e \x01(\r\x12\x17\n\x0fmeta_xp_awarded\x18\x0f \x01(\r\x12<\n\rleaver_status\x18\x10 \x01(\x0e\x32\x13.DOTALeaverStatus_t:\x10\x44OTA_LEAVER_NONE\x12\x16\n\x0eleaver_actions\x18\x1c \x01(\r\x12\x0f\n\x07\x63hannel\x18\x11 \x01(\r\x12\x17\n\x0fprize_def_index\x18\x12 \x01(\r\x12\x18\n\x10\x64isabled_hero_id\x18\x14 \x03(\r\x12?\n\x14partner_account_type\x18\x15 \x01(\x0e\x32\x13.PartnerAccountType:\x0cPARTNER_NONE\x12\x17\n\x0f\x65nabled_hero_id\x18\x16 \x03(\r\x12\x36\n\ncoach_team\x18\x17 \x01(\x0e\x32\r.DOTA_GC_TEAM:\x13\x44OTA_GC_TEAM_NOTEAM\x12\x18\n\x10nexon_pc_bang_no\x18\x18 \x01(\r\x12\x1a\n\x12nexon_pc_bang_name\x18\x19 \x01(\t\x12=\n\nxp_bonuses\x18\x1b \x03(\x0b\x32).CDOTALobbyMember.CDOTALobbyMemberXPBonus\x12\x13\n\x0brank_change\x18\x1d \x01(\x11\x12\x11\n\tcameraman\x18\x1e \x01(\x08\x12\x1f\n\x17\x63ustom_game_product_ids\x18\x1f \x03(\r\x12!\n\x19lobby_mvp_vote_account_id\x18  \x01(\r\x12\x38\n\x11search_match_type\x18! \x01(\x0e\x32\n.MatchType:\x11MATCH_TYPE_CASUAL\x12!\n\x19\x66\x61vorite_team_and_quality\x18\" \x01(\r\x1aM\n\x17\x43\x44OTALobbyMemberXPBonus\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x10\n\x08xp_bonus\x18\x02 \x01(\x02\x12\x12\n\nsource_key\x18\x03 \x01(\x04\"\xdf\x02\n\x11\x43LobbyTeamDetails\x12\x11\n\tteam_name\x18\x01 \x01(\t\x12\x10\n\x08team_tag\x18\x03 \x01(\t\x12\x0f\n\x07team_id\x18\x04 \x01(\r\x12\x11\n\tteam_logo\x18\x05 \x01(\x04\x12\x16\n\x0eteam_base_logo\x18\x06 \x01(\x04\x12\x18\n\x10team_banner_logo\x18\x07 \x01(\x04\x12\x15\n\rteam_complete\x18\x08 \x01(\x08\x12\x12\n\nguild_name\x18\t \x01(\t\x12\x11\n\tguild_tag\x18\n \x01(\t\x12\x10\n\x08guild_id\x18\x0b \x01(\r\x12\x12\n\nguild_logo\x18\x0c \x01(\x04\x12\x17\n\x0fguild_base_logo\x18\r \x01(\x04\x12\x19\n\x11guild_banner_logo\x18\x0e \x01(\x04\x12\x0c\n\x04rank\x18\x0f \x01(\r\x12\x13\n\x0brank_change\x18\x10 \x01(\x11\x12\x14\n\x0cis_home_team\x18\x11 \x01(\x08\"\x86\x01\n\x18\x43LobbyTimedRewardDetails\x12\x16\n\x0eitem_def_index\x18\x02 \x01(\r\x12\x17\n\x0fis_supply_crate\x18\x03 \x01(\x08\x12\x15\n\ris_timed_drop\x18\x04 \x01(\x08\x12\x12\n\naccount_id\x18\x05 \x01(\r\x12\x0e\n\x06origin\x18\x06 \x01(\r\"r\n\x1a\x43LobbyBroadcastChannelInfo\x12\x12\n\nchannel_id\x18\x01 \x01(\r\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x15\n\rlanguage_code\x18\x04 \x01(\t\"\xf7\x18\n\x0c\x43SODOTALobby\x12\x16\n\x08lobby_id\x18\x01 \x01(\x04\x42\x04\x80\x97\"\x01\x12\"\n\x07members\x18\x02 \x03(\x0b\x32\x11.CDOTALobbyMember\x12\'\n\x0cleft_members\x18\x07 \x03(\x0b\x32\x11.CDOTALobbyMember\x12\x11\n\tleader_id\x18\x0b \x01(\x06\x12\x14\n\tserver_id\x18\x06 \x01(\x06:\x01\x30\x12\x11\n\tgame_mode\x18\x03 \x01(\r\x12\x17\n\x0fpending_invites\x18\n \x03(\x06\x12&\n\x05state\x18\x04 \x01(\x0e\x32\x13.CSODOTALobby.State:\x02UI\x12\x0f\n\x07\x63onnect\x18\x05 \x01(\t\x12\x34\n\nlobby_type\x18\x0c \x01(\x0e\x32\x17.CSODOTALobby.LobbyType:\x07INVALID\x12\x14\n\x0c\x61llow_cheats\x18\r \x01(\x08\x12\x16\n\x0e\x66ill_with_bots\x18\x0e \x01(\x08\x12\x12\n\nintro_mode\x18\x0f \x01(\x08\x12\x11\n\tgame_name\x18\x10 \x01(\t\x12(\n\x0cteam_details\x18\x11 \x03(\x0b\x32\x12.CLobbyTeamDetails\x12\x17\n\x0ftutorial_lesson\x18\x12 \x01(\r\x12\x15\n\rtournament_id\x18\x13 \x01(\r\x12\x1a\n\x12tournament_game_id\x18\x14 \x01(\r\x12\x18\n\rserver_region\x18\x15 \x01(\r:\x01\x30\x12>\n\ngame_state\x18\x16 \x01(\x0e\x32\x0f.DOTA_GameState:\x19\x44OTA_GAMERULES_STATE_INIT\x12\x16\n\x0enum_spectators\x18\x17 \x01(\r\x12\x12\n\nmatchgroup\x18\x19 \x01(\r\x12.\n\x07\x63m_pick\x18\x1c \x01(\x0e\x32\r.DOTA_CM_PICK:\x0e\x44OTA_CM_RANDOM\x12\x10\n\x08match_id\x18\x1e \x01(\x04\x12\x1e\n\x10\x61llow_spectating\x18\x1f \x01(\x08:\x04true\x12G\n\x16\x62ot_difficulty_radiant\x18$ \x01(\x0e\x32\x12.DOTABotDifficulty:\x13\x42OT_DIFFICULTY_HARD\x12<\n\x0cgame_version\x18% \x01(\x0e\x32\x10.DOTAGameVersion:\x14GAME_VERSION_CURRENT\x12\x37\n\x14timed_reward_details\x18& \x03(\x0b\x32\x19.CLobbyTimedRewardDetails\x12\x10\n\x08pass_key\x18\' \x01(\t\x12\x10\n\x08leagueid\x18* \x01(\r\x12 \n\x15penalty_level_radiant\x18+ \x01(\r:\x01\x30\x12\x1d\n\x12penalty_level_dire\x18, \x01(\r:\x01\x30\x12\x14\n\x0cload_game_id\x18- \x01(\r\x12\x13\n\x0bseries_type\x18. \x01(\r\x12\x1b\n\x13radiant_series_wins\x18/ \x01(\r\x12\x18\n\x10\x64ire_series_wins\x18\x30 \x01(\r\x12\x16\n\x0eloot_generated\x18\x31 \x01(\r\x12\x14\n\x0cloot_awarded\x18\x32 \x01(\r\x12\x16\n\x07\x61llchat\x18\x33 \x01(\x08:\x05\x66\x61lse\x12\x38\n\rdota_tv_delay\x18\x35 \x01(\x0e\x32\x11.LobbyDotaTVDelay:\x0eLobbyDotaTV_10\x12\x18\n\x10\x63ustom_game_mode\x18\x36 \x01(\t\x12\x17\n\x0f\x63ustom_map_name\x18\x37 \x01(\t\x12\x19\n\x11\x63ustom_difficulty\x18\x38 \x01(\r\x12\x0b\n\x03lan\x18\x39 \x01(\x08\x12;\n\x16\x62roadcast_channel_info\x18: \x03(\x0b\x32\x1b.CLobbyBroadcastChannelInfo\x12\x1e\n\x16\x66irst_leaver_accountid\x18; \x01(\r\x12\x11\n\tseries_id\x18< \x01(\r\x12\x14\n\x0clow_priority\x18= \x01(\x08\x12/\n\x0e\x65xtra_messages\x18> \x03(\x0b\x32\x17.CSODOTALobby.CExtraMsg\x12!\n\tsave_game\x18? \x01(\x0b\x32\x0e.CDOTASaveGame\x12\x1c\n\x14\x66irst_blood_happened\x18\x41 \x01(\x08\x12>\n\rmatch_outcome\x18\x46 \x01(\x0e\x32\x0e.EMatchOutcome:\x17k_EMatchOutcome_Unknown\x12\x17\n\x0fmass_disconnect\x18\x43 \x01(\x08\x12\x16\n\x0e\x63ustom_game_id\x18\x44 \x01(\x04\x12%\n\x14\x61\x63tive_ingame_events\x18\x45 \x03(\x0e\x32\x07.EEvent\x12\x1a\n\x12\x63ustom_min_players\x18G \x01(\r\x12\x1a\n\x12\x63ustom_max_players\x18H \x01(\r\x12\x37\n\x0cpartner_type\x18I \x01(\x0e\x32\x13.PartnerAccountType:\x0cPARTNER_NONE\x12&\n\x1elan_host_ping_to_server_region\x18J \x01(\r\x12\x44\n\nvisibility\x18K \x01(\x0e\x32\x14.DOTALobbyVisibility:\x1a\x44OTALobbyVisibility_Public\x12\x17\n\x0f\x63ustom_game_crc\x18L \x01(\x06\x12&\n\x1e\x63ustom_game_auto_created_lobby\x18M \x01(\x08\x12\x18\n\x10league_series_id\x18N \x01(\r\x12\x16\n\x0eleague_game_id\x18O \x01(\r\x12\x1d\n\x15\x63ustom_game_timestamp\x18P \x01(\x07\x12\x1f\n\x17previous_series_matches\x18Q \x03(\x04\x12\x1f\n\x17previous_match_override\x18R \x01(\x04\x12(\n custom_game_uses_account_records\x18S \x01(\x08\x12&\n\x1eleague_selection_priority_team\x18T \x01(\r\x12K\n league_selection_priority_choice\x18U \x01(\x0e\x32\x16.SelectionPriorityType:\tUNDEFINED\x12O\n$league_non_selection_priority_choice\x18V \x01(\x0e\x32\x16.SelectionPriorityType:\tUNDEFINED\x12\x17\n\x0fgame_start_time\x18W \x01(\r\x12N\n\rpause_setting\x18X \x01(\x0e\x32\x16.LobbyDotaPauseSetting:\x1fLobbyDotaPauseSetting_Unlimited\x12\x1c\n\x14lobby_mvp_account_id\x18Y \x01(\r\x12#\n\x1bweekend_tourney_division_id\x18Z \x01(\r\x12#\n\x1bweekend_tourney_skill_level\x18[ \x01(\r\x12%\n\x1dweekend_tourney_bracket_round\x18\\ \x01(\r\x12\x44\n\x13\x62ot_difficulty_dire\x18] \x01(\x0e\x32\x12.DOTABotDifficulty:\x13\x42OT_DIFFICULTY_HARD\x12\x13\n\x0b\x62ot_radiant\x18^ \x01(\x04\x12\x10\n\x08\x62ot_dire\x18_ \x01(\x04\x1a)\n\tCExtraMsg\x12\n\n\x02id\x18\x01 \x01(\r\x12\x10\n\x08\x63ontents\x18\x02 \x01(\x0c\"d\n\x05State\x12\x06\n\x02UI\x10\x00\x12\x0b\n\x07READYUP\x10\x04\x12\x0f\n\x0bSERVERSETUP\x10\x01\x12\x07\n\x03RUN\x10\x02\x12\x0c\n\x08POSTGAME\x10\x03\x12\x0c\n\x08NOTREADY\x10\x05\x12\x10\n\x0cSERVERASSIGN\x10\x06\"\xff\x01\n\tLobbyType\x12\x14\n\x07INVALID\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x10\n\x0c\x43\x41SUAL_MATCH\x10\x00\x12\x0c\n\x08PRACTICE\x10\x01\x12\x0e\n\nTOURNAMENT\x10\x02\x12\x12\n\x0e\x43OOP_BOT_MATCH\x10\x04\x12\x15\n\x11LEGACY_TEAM_MATCH\x10\x05\x12\x1b\n\x17LEGACY_SOLO_QUEUE_MATCH\x10\x06\x12\x15\n\x11\x43OMPETITIVE_MATCH\x10\x07\x12\x14\n\x10\x43\x41SUAL_1V1_MATCH\x10\x08\x12\x13\n\x0fWEEKEND_TOURNEY\x10\t\x12\x13\n\x0fLOCAL_BOT_MATCH\x10\n\x12\r\n\tSPECTATOR\x10\x0b*P\n\x10LobbyDotaTVDelay\x12\x12\n\x0eLobbyDotaTV_10\x10\x00\x12\x13\n\x0fLobbyDotaTV_120\x10\x01\x12\x13\n\x0fLobbyDotaTV_300\x10\x02*\x83\x01\n\x15LobbyDotaPauseSetting\x12#\n\x1fLobbyDotaPauseSetting_Unlimited\x10\x00\x12!\n\x1dLobbyDotaPauseSetting_Limited\x10\x01\x12\"\n\x1eLobbyDotaPauseSetting_Disabled\x10\x02\x42\x05H\x01\x90\x01\x00')
  ,
  dependencies=[steammessages__pb2.DESCRIPTOR,gcsdk__gcmessages__pb2.DESCRIPTOR,dota__shared__enums__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_LOBBYDOTATVDELAY = _descriptor.EnumDescriptor(
  name='LobbyDotaTVDelay',
  full_name='LobbyDotaTVDelay',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LobbyDotaTV_10', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LobbyDotaTV_120', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LobbyDotaTV_300', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7364,
  serialized_end=7444,
)
_sym_db.RegisterEnumDescriptor(_LOBBYDOTATVDELAY)

LobbyDotaTVDelay = enum_type_wrapper.EnumTypeWrapper(_LOBBYDOTATVDELAY)
_LOBBYDOTAPAUSESETTING = _descriptor.EnumDescriptor(
  name='LobbyDotaPauseSetting',
  full_name='LobbyDotaPauseSetting',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LobbyDotaPauseSetting_Unlimited', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LobbyDotaPauseSetting_Limited', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LobbyDotaPauseSetting_Disabled', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7447,
  serialized_end=7578,
)
_sym_db.RegisterEnumDescriptor(_LOBBYDOTAPAUSESETTING)

LobbyDotaPauseSetting = enum_type_wrapper.EnumTypeWrapper(_LOBBYDOTAPAUSESETTING)
LobbyDotaTV_10 = 0
LobbyDotaTV_120 = 1
LobbyDotaTV_300 = 2
LobbyDotaPauseSetting_Unlimited = 0
LobbyDotaPauseSetting_Limited = 1
LobbyDotaPauseSetting_Disabled = 2


_CSODOTAPARTY_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='CSODOTAParty.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UI', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINDING_MATCH', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN_MATCH', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1813,
  serialized_end=1861,
)
_sym_db.RegisterEnumDescriptor(_CSODOTAPARTY_STATE)

_CSODOTALOBBY_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='CSODOTALobby.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UI', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READYUP', index=1, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVERSETUP', index=2, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUN', index=3, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POSTGAME', index=4, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOTREADY', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVERASSIGN', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7004,
  serialized_end=7104,
)
_sym_db.RegisterEnumDescriptor(_CSODOTALOBBY_STATE)

_CSODOTALOBBY_LOBBYTYPE = _descriptor.EnumDescriptor(
  name='LobbyType',
  full_name='CSODOTALobby.LobbyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=0, number=-1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CASUAL_MATCH', index=1, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRACTICE', index=2, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOURNAMENT', index=3, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COOP_BOT_MATCH', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEGACY_TEAM_MATCH', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEGACY_SOLO_QUEUE_MATCH', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPETITIVE_MATCH', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CASUAL_1V1_MATCH', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKEND_TOURNEY', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCAL_BOT_MATCH', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPECTATOR', index=11, number=11,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7107,
  serialized_end=7362,
)
_sym_db.RegisterEnumDescriptor(_CSODOTALOBBY_LOBBYTYPE)


_CSODOTAPARTYMEMBER = _descriptor.Descriptor(
  name='CSODOTAPartyMember',
  full_name='CSODOTAPartyMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partner_type', full_name='CSODOTAPartyMember.partner_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_coach', full_name='CSODOTAPartyMember.is_coach', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='region_ping_codes', full_name='CSODOTAPartyMember.region_ping_codes', index=2,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='region_ping_times', full_name='CSODOTAPartyMember.region_ping_times', index=3,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='region_ping_failed_bitmask', full_name='CSODOTAPartyMember.region_ping_failed_bitmask', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_skill_level', full_name='CSODOTAPartyMember.tourney_skill_level', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_buyin', full_name='CSODOTAPartyMember.tourney_buyin', index=6,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_prevent_until', full_name='CSODOTAPartyMember.tourney_prevent_until', index=7,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=396,
)


_CSODOTAPARTY = _descriptor.Descriptor(
  name='CSODOTAParty',
  full_name='CSODOTAParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='party_id', full_name='CSODOTAParty.party_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='leader_id', full_name='CSODOTAParty.leader_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_ids', full_name='CSODOTAParty.member_ids', index=2,
      number=3, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_modes', full_name='CSODOTAParty.game_modes', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='CSODOTAParty.state', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='effective_started_matchmaking_time', full_name='CSODOTAParty.effective_started_matchmaking_time', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raw_started_matchmaking_time', full_name='CSODOTAParty.raw_started_matchmaking_time', index=6,
      number=32, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attempt_start_time', full_name='CSODOTAParty.attempt_start_time', index=7,
      number=33, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attempt_num', full_name='CSODOTAParty.attempt_num', index=8,
      number=34, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matchgroups', full_name='CSODOTAParty.matchgroups', index=9,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='low_priority_account_id', full_name='CSODOTAParty.low_priority_account_id', index=10,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_type', full_name='CSODOTAParty.match_type', index=11,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bot_difficulty', full_name='CSODOTAParty.bot_difficulty', index=12,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CSODOTAParty.team_id', index=13,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CSODOTAParty.team_name', index=14,
      number=51, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_ui_logo', full_name='CSODOTAParty.team_ui_logo', index=15,
      number=52, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_base_logo', full_name='CSODOTAParty.team_base_logo', index=16,
      number=53, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_disabled_until_date', full_name='CSODOTAParty.match_disabled_until_date', index=17,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_disabled_account_id', full_name='CSODOTAParty.match_disabled_account_id', index=18,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matchmaking_max_range_minutes', full_name='CSODOTAParty.matchmaking_max_range_minutes', index=19,
      number=26, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matchlanguages', full_name='CSODOTAParty.matchlanguages', index=20,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map_preference', full_name='CSODOTAParty.map_preference', index=21,
      number=38, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='members', full_name='CSODOTAParty.members', index=22,
      number=29, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='open_guild_id', full_name='CSODOTAParty.open_guild_id', index=23,
      number=30, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common_guilds', full_name='CSODOTAParty.common_guilds', index=24,
      number=31, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='low_priority_games_remaining', full_name='CSODOTAParty.low_priority_games_remaining', index=25,
      number=35, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active_ingame_events', full_name='CSODOTAParty.active_ingame_events', index=26,
      number=39, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='open_for_join_requests', full_name='CSODOTAParty.open_for_join_requests', index=27,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sent_invites', full_name='CSODOTAParty.sent_invites', index=28,
      number=41, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recv_invites', full_name='CSODOTAParty.recv_invites', index=29,
      number=42, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_flags', full_name='CSODOTAParty.account_flags', index=30,
      number=43, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='region_select_flags', full_name='CSODOTAParty.region_select_flags', index=31,
      number=44, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exclusive_tournament_id', full_name='CSODOTAParty.exclusive_tournament_id', index=32,
      number=45, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_division_id', full_name='CSODOTAParty.tourney_division_id', index=33,
      number=47, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_schedule_time', full_name='CSODOTAParty.tourney_schedule_time', index=34,
      number=48, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_skill_level', full_name='CSODOTAParty.tourney_skill_level', index=35,
      number=49, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_bracket_round', full_name='CSODOTAParty.tourney_bracket_round', index=36,
      number=50, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_queue_deadline_time', full_name='CSODOTAParty.tourney_queue_deadline_time', index=37,
      number=54, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_queue_deadline_state', full_name='CSODOTAParty.tourney_queue_deadline_state', index=38,
      number=55, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='party_builder_slots_to_fill', full_name='CSODOTAParty.party_builder_slots_to_fill', index=39,
      number=56, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='party_builder_match_groups', full_name='CSODOTAParty.party_builder_match_groups', index=40,
      number=57, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='party_builder_start_time', full_name='CSODOTAParty.party_builder_start_time', index=41,
      number=58, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CSODOTAPARTY_STATE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=1861,
)


_CSODOTAPARTYINVITE_PARTYMEMBER = _descriptor.Descriptor(
  name='PartyMember',
  full_name='CSODOTAPartyInvite.PartyMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CSODOTAPartyInvite.PartyMember.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CSODOTAPartyInvite.PartyMember.steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_coach', full_name='CSODOTAPartyInvite.PartyMember.is_coach', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2084,
  serialized_end=2147,
)

_CSODOTAPARTYINVITE = _descriptor.Descriptor(
  name='CSODOTAPartyInvite',
  full_name='CSODOTAPartyInvite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='CSODOTAPartyInvite.group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='CSODOTAPartyInvite.sender_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sender_name', full_name='CSODOTAPartyInvite.sender_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='members', full_name='CSODOTAPartyInvite.members', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CSODOTAPartyInvite.team_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='low_priority_status', full_name='CSODOTAPartyInvite.low_priority_status', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='as_coach', full_name='CSODOTAPartyInvite.as_coach', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invite_gid', full_name='CSODOTAPartyInvite.invite_gid', index=7,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CSODOTAPARTYINVITE_PARTYMEMBER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1864,
  serialized_end=2147,
)


_CSODOTALOBBYINVITE_LOBBYMEMBER = _descriptor.Descriptor(
  name='LobbyMember',
  full_name='CSODOTALobbyInvite.LobbyMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CSODOTALobbyInvite.LobbyMember.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CSODOTALobbyInvite.LobbyMember.steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2386,
  serialized_end=2431,
)

_CSODOTALOBBYINVITE = _descriptor.Descriptor(
  name='CSODOTALobbyInvite',
  full_name='CSODOTALobbyInvite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='CSODOTALobbyInvite.group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='CSODOTALobbyInvite.sender_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sender_name', full_name='CSODOTALobbyInvite.sender_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='members', full_name='CSODOTALobbyInvite.members', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CSODOTALobbyInvite.custom_game_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invite_gid', full_name='CSODOTALobbyInvite.invite_gid', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_crc', full_name='CSODOTALobbyInvite.custom_game_crc', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_timestamp', full_name='CSODOTALobbyInvite.custom_game_timestamp', index=7,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CSODOTALOBBYINVITE_LOBBYMEMBER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2150,
  serialized_end=2431,
)


_CMSGLEAVERSTATE = _descriptor.Descriptor(
  name='CMsgLeaverState',
  full_name='CMsgLeaverState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_state', full_name='CMsgLeaverState.lobby_state', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_state', full_name='CMsgLeaverState.game_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leaver_detected', full_name='CMsgLeaverState.leaver_detected', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_blood_happened', full_name='CMsgLeaverState.first_blood_happened', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='discard_match_results', full_name='CMsgLeaverState.discard_match_results', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mass_disconnect', full_name='CMsgLeaverState.mass_disconnect', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2434,
  serialized_end=2647,
)


_CDOTALOBBYMEMBER_CDOTALOBBYMEMBERXPBONUS = _descriptor.Descriptor(
  name='CDOTALobbyMemberXPBonus',
  full_name='CDOTALobbyMember.CDOTALobbyMemberXPBonus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CDOTALobbyMember.CDOTALobbyMemberXPBonus.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xp_bonus', full_name='CDOTALobbyMember.CDOTALobbyMemberXPBonus.xp_bonus', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source_key', full_name='CDOTALobbyMember.CDOTALobbyMemberXPBonus.source_key', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3484,
  serialized_end=3561,
)

_CDOTALOBBYMEMBER = _descriptor.Descriptor(
  name='CDOTALobbyMember',
  full_name='CDOTALobbyMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CDOTALobbyMember.id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CDOTALobbyMember.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team', full_name='CDOTALobbyMember.team', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CDOTALobbyMember.name', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot', full_name='CDOTALobbyMember.slot', index=4,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='party_id', full_name='CDOTALobbyMember.party_id', index=5,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='meta_level', full_name='CDOTALobbyMember.meta_level', index=6,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='meta_xp', full_name='CDOTALobbyMember.meta_xp', index=7,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='meta_xp_awarded', full_name='CDOTALobbyMember.meta_xp_awarded', index=8,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leaver_status', full_name='CDOTALobbyMember.leaver_status', index=9,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leaver_actions', full_name='CDOTALobbyMember.leaver_actions', index=10,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel', full_name='CDOTALobbyMember.channel', index=11,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prize_def_index', full_name='CDOTALobbyMember.prize_def_index', index=12,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='disabled_hero_id', full_name='CDOTALobbyMember.disabled_hero_id', index=13,
      number=20, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partner_account_type', full_name='CDOTALobbyMember.partner_account_type', index=14,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enabled_hero_id', full_name='CDOTALobbyMember.enabled_hero_id', index=15,
      number=22, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coach_team', full_name='CDOTALobbyMember.coach_team', index=16,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=5,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nexon_pc_bang_no', full_name='CDOTALobbyMember.nexon_pc_bang_no', index=17,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nexon_pc_bang_name', full_name='CDOTALobbyMember.nexon_pc_bang_name', index=18,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xp_bonuses', full_name='CDOTALobbyMember.xp_bonuses', index=19,
      number=27, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rank_change', full_name='CDOTALobbyMember.rank_change', index=20,
      number=29, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cameraman', full_name='CDOTALobbyMember.cameraman', index=21,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_product_ids', full_name='CDOTALobbyMember.custom_game_product_ids', index=22,
      number=31, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_mvp_vote_account_id', full_name='CDOTALobbyMember.lobby_mvp_vote_account_id', index=23,
      number=32, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='search_match_type', full_name='CDOTALobbyMember.search_match_type', index=24,
      number=33, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='favorite_team_and_quality', full_name='CDOTALobbyMember.favorite_team_and_quality', index=25,
      number=34, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CDOTALOBBYMEMBER_CDOTALOBBYMEMBERXPBONUS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2650,
  serialized_end=3561,
)


_CLOBBYTEAMDETAILS = _descriptor.Descriptor(
  name='CLobbyTeamDetails',
  full_name='CLobbyTeamDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CLobbyTeamDetails.team_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_tag', full_name='CLobbyTeamDetails.team_tag', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CLobbyTeamDetails.team_id', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_logo', full_name='CLobbyTeamDetails.team_logo', index=3,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_base_logo', full_name='CLobbyTeamDetails.team_base_logo', index=4,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_banner_logo', full_name='CLobbyTeamDetails.team_banner_logo', index=5,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_complete', full_name='CLobbyTeamDetails.team_complete', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guild_name', full_name='CLobbyTeamDetails.guild_name', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guild_tag', full_name='CLobbyTeamDetails.guild_tag', index=8,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CLobbyTeamDetails.guild_id', index=9,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guild_logo', full_name='CLobbyTeamDetails.guild_logo', index=10,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guild_base_logo', full_name='CLobbyTeamDetails.guild_base_logo', index=11,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guild_banner_logo', full_name='CLobbyTeamDetails.guild_banner_logo', index=12,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rank', full_name='CLobbyTeamDetails.rank', index=13,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rank_change', full_name='CLobbyTeamDetails.rank_change', index=14,
      number=16, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_home_team', full_name='CLobbyTeamDetails.is_home_team', index=15,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3564,
  serialized_end=3915,
)


_CLOBBYTIMEDREWARDDETAILS = _descriptor.Descriptor(
  name='CLobbyTimedRewardDetails',
  full_name='CLobbyTimedRewardDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def_index', full_name='CLobbyTimedRewardDetails.item_def_index', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_supply_crate', full_name='CLobbyTimedRewardDetails.is_supply_crate', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_timed_drop', full_name='CLobbyTimedRewardDetails.is_timed_drop', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CLobbyTimedRewardDetails.account_id', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin', full_name='CLobbyTimedRewardDetails.origin', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3918,
  serialized_end=4052,
)


_CLOBBYBROADCASTCHANNELINFO = _descriptor.Descriptor(
  name='CLobbyBroadcastChannelInfo',
  full_name='CLobbyBroadcastChannelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CLobbyBroadcastChannelInfo.channel_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CLobbyBroadcastChannelInfo.country_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='CLobbyBroadcastChannelInfo.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='CLobbyBroadcastChannelInfo.language_code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4054,
  serialized_end=4168,
)


_CSODOTALOBBY_CEXTRAMSG = _descriptor.Descriptor(
  name='CExtraMsg',
  full_name='CSODOTALobby.CExtraMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CSODOTALobby.CExtraMsg.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contents', full_name='CSODOTALobby.CExtraMsg.contents', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6961,
  serialized_end=7002,
)

_CSODOTALOBBY = _descriptor.Descriptor(
  name='CSODOTALobby',
  full_name='CSODOTALobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CSODOTALobby.lobby_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='members', full_name='CSODOTALobby.members', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='left_members', full_name='CSODOTALobby.left_members', index=2,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leader_id', full_name='CSODOTALobby.leader_id', index=3,
      number=11, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_id', full_name='CSODOTALobby.server_id', index=4,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CSODOTALobby.game_mode', index=5,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pending_invites', full_name='CSODOTALobby.pending_invites', index=6,
      number=10, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='CSODOTALobby.state', index=7,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='connect', full_name='CSODOTALobby.connect', index=8,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CSODOTALobby.lobby_type', index=9,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='allow_cheats', full_name='CSODOTALobby.allow_cheats', index=10,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fill_with_bots', full_name='CSODOTALobby.fill_with_bots', index=11,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='intro_mode', full_name='CSODOTALobby.intro_mode', index=12,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_name', full_name='CSODOTALobby.game_name', index=13,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_details', full_name='CSODOTALobby.team_details', index=14,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tutorial_lesson', full_name='CSODOTALobby.tutorial_lesson', index=15,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_id', full_name='CSODOTALobby.tournament_id', index=16,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_game_id', full_name='CSODOTALobby.tournament_game_id', index=17,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_region', full_name='CSODOTALobby.server_region', index=18,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_state', full_name='CSODOTALobby.game_state', index=19,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_spectators', full_name='CSODOTALobby.num_spectators', index=20,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matchgroup', full_name='CSODOTALobby.matchgroup', index=21,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cm_pick', full_name='CSODOTALobby.cm_pick', index=22,
      number=28, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CSODOTALobby.match_id', index=23,
      number=30, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='allow_spectating', full_name='CSODOTALobby.allow_spectating', index=24,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bot_difficulty_radiant', full_name='CSODOTALobby.bot_difficulty_radiant', index=25,
      number=36, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_version', full_name='CSODOTALobby.game_version', index=26,
      number=37, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timed_reward_details', full_name='CSODOTALobby.timed_reward_details', index=27,
      number=38, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pass_key', full_name='CSODOTALobby.pass_key', index=28,
      number=39, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leagueid', full_name='CSODOTALobby.leagueid', index=29,
      number=42, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='penalty_level_radiant', full_name='CSODOTALobby.penalty_level_radiant', index=30,
      number=43, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='penalty_level_dire', full_name='CSODOTALobby.penalty_level_dire', index=31,
      number=44, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='load_game_id', full_name='CSODOTALobby.load_game_id', index=32,
      number=45, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_type', full_name='CSODOTALobby.series_type', index=33,
      number=46, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_series_wins', full_name='CSODOTALobby.radiant_series_wins', index=34,
      number=47, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dire_series_wins', full_name='CSODOTALobby.dire_series_wins', index=35,
      number=48, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='loot_generated', full_name='CSODOTALobby.loot_generated', index=36,
      number=49, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='loot_awarded', full_name='CSODOTALobby.loot_awarded', index=37,
      number=50, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='allchat', full_name='CSODOTALobby.allchat', index=38,
      number=51, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dota_tv_delay', full_name='CSODOTALobby.dota_tv_delay', index=39,
      number=53, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_mode', full_name='CSODOTALobby.custom_game_mode', index=40,
      number=54, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_map_name', full_name='CSODOTALobby.custom_map_name', index=41,
      number=55, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_difficulty', full_name='CSODOTALobby.custom_difficulty', index=42,
      number=56, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lan', full_name='CSODOTALobby.lan', index=43,
      number=57, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='broadcast_channel_info', full_name='CSODOTALobby.broadcast_channel_info', index=44,
      number=58, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_leaver_accountid', full_name='CSODOTALobby.first_leaver_accountid', index=45,
      number=59, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_id', full_name='CSODOTALobby.series_id', index=46,
      number=60, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='low_priority', full_name='CSODOTALobby.low_priority', index=47,
      number=61, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='extra_messages', full_name='CSODOTALobby.extra_messages', index=48,
      number=62, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='save_game', full_name='CSODOTALobby.save_game', index=49,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_blood_happened', full_name='CSODOTALobby.first_blood_happened', index=50,
      number=65, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_outcome', full_name='CSODOTALobby.match_outcome', index=51,
      number=70, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mass_disconnect', full_name='CSODOTALobby.mass_disconnect', index=52,
      number=67, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CSODOTALobby.custom_game_id', index=53,
      number=68, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active_ingame_events', full_name='CSODOTALobby.active_ingame_events', index=54,
      number=69, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_min_players', full_name='CSODOTALobby.custom_min_players', index=55,
      number=71, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_max_players', full_name='CSODOTALobby.custom_max_players', index=56,
      number=72, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partner_type', full_name='CSODOTALobby.partner_type', index=57,
      number=73, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lan_host_ping_to_server_region', full_name='CSODOTALobby.lan_host_ping_to_server_region', index=58,
      number=74, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='CSODOTALobby.visibility', index=59,
      number=75, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_crc', full_name='CSODOTALobby.custom_game_crc', index=60,
      number=76, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_auto_created_lobby', full_name='CSODOTALobby.custom_game_auto_created_lobby', index=61,
      number=77, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_series_id', full_name='CSODOTALobby.league_series_id', index=62,
      number=78, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_game_id', full_name='CSODOTALobby.league_game_id', index=63,
      number=79, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_timestamp', full_name='CSODOTALobby.custom_game_timestamp', index=64,
      number=80, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='previous_series_matches', full_name='CSODOTALobby.previous_series_matches', index=65,
      number=81, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='previous_match_override', full_name='CSODOTALobby.previous_match_override', index=66,
      number=82, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_uses_account_records', full_name='CSODOTALobby.custom_game_uses_account_records', index=67,
      number=83, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_selection_priority_team', full_name='CSODOTALobby.league_selection_priority_team', index=68,
      number=84, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_selection_priority_choice', full_name='CSODOTALobby.league_selection_priority_choice', index=69,
      number=85, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_non_selection_priority_choice', full_name='CSODOTALobby.league_non_selection_priority_choice', index=70,
      number=86, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_start_time', full_name='CSODOTALobby.game_start_time', index=71,
      number=87, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pause_setting', full_name='CSODOTALobby.pause_setting', index=72,
      number=88, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_mvp_account_id', full_name='CSODOTALobby.lobby_mvp_account_id', index=73,
      number=89, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weekend_tourney_division_id', full_name='CSODOTALobby.weekend_tourney_division_id', index=74,
      number=90, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weekend_tourney_skill_level', full_name='CSODOTALobby.weekend_tourney_skill_level', index=75,
      number=91, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weekend_tourney_bracket_round', full_name='CSODOTALobby.weekend_tourney_bracket_round', index=76,
      number=92, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bot_difficulty_dire', full_name='CSODOTALobby.bot_difficulty_dire', index=77,
      number=93, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bot_radiant', full_name='CSODOTALobby.bot_radiant', index=78,
      number=94, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bot_dire', full_name='CSODOTALobby.bot_dire', index=79,
      number=95, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CSODOTALOBBY_CEXTRAMSG, ],
  enum_types=[
    _CSODOTALOBBY_STATE,
    _CSODOTALOBBY_LOBBYTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4171,
  serialized_end=7362,
)

_CSODOTAPARTYMEMBER.fields_by_name['partner_type'].enum_type = gcsdk__gcmessages__pb2._PARTNERACCOUNTTYPE
_CSODOTAPARTY.fields_by_name['state'].enum_type = _CSODOTAPARTY_STATE
_CSODOTAPARTY.fields_by_name['match_type'].enum_type = dota__shared__enums__pb2._MATCHTYPE
_CSODOTAPARTY.fields_by_name['bot_difficulty'].enum_type = dota__shared__enums__pb2._DOTABOTDIFFICULTY
_CSODOTAPARTY.fields_by_name['members'].message_type = _CSODOTAPARTYMEMBER
_CSODOTAPARTY.fields_by_name['active_ingame_events'].enum_type = dota__shared__enums__pb2._EEVENT
_CSODOTAPARTY.fields_by_name['sent_invites'].message_type = _CSODOTAPARTYINVITE
_CSODOTAPARTY.fields_by_name['recv_invites'].message_type = _CSODOTAPARTYINVITE
_CSODOTAPARTY.fields_by_name['tourney_queue_deadline_state'].enum_type = dota__shared__enums__pb2._ETOURNEYQUEUEDEADLINESTATE
_CSODOTAPARTY_STATE.containing_type = _CSODOTAPARTY
_CSODOTAPARTYINVITE_PARTYMEMBER.containing_type = _CSODOTAPARTYINVITE
_CSODOTAPARTYINVITE.fields_by_name['members'].message_type = _CSODOTAPARTYINVITE_PARTYMEMBER
_CSODOTALOBBYINVITE_LOBBYMEMBER.containing_type = _CSODOTALOBBYINVITE
_CSODOTALOBBYINVITE.fields_by_name['members'].message_type = _CSODOTALOBBYINVITE_LOBBYMEMBER
_CMSGLEAVERSTATE.fields_by_name['game_state'].enum_type = dota__shared__enums__pb2._DOTA_GAMESTATE
_CDOTALOBBYMEMBER_CDOTALOBBYMEMBERXPBONUS.containing_type = _CDOTALOBBYMEMBER
_CDOTALOBBYMEMBER.fields_by_name['team'].enum_type = dota__shared__enums__pb2._DOTA_GC_TEAM
_CDOTALOBBYMEMBER.fields_by_name['leaver_status'].enum_type = dota__shared__enums__pb2._DOTALEAVERSTATUS_T
_CDOTALOBBYMEMBER.fields_by_name['partner_account_type'].enum_type = gcsdk__gcmessages__pb2._PARTNERACCOUNTTYPE
_CDOTALOBBYMEMBER.fields_by_name['coach_team'].enum_type = dota__shared__enums__pb2._DOTA_GC_TEAM
_CDOTALOBBYMEMBER.fields_by_name['xp_bonuses'].message_type = _CDOTALOBBYMEMBER_CDOTALOBBYMEMBERXPBONUS
_CDOTALOBBYMEMBER.fields_by_name['search_match_type'].enum_type = dota__shared__enums__pb2._MATCHTYPE
_CSODOTALOBBY_CEXTRAMSG.containing_type = _CSODOTALOBBY
_CSODOTALOBBY.fields_by_name['members'].message_type = _CDOTALOBBYMEMBER
_CSODOTALOBBY.fields_by_name['left_members'].message_type = _CDOTALOBBYMEMBER
_CSODOTALOBBY.fields_by_name['state'].enum_type = _CSODOTALOBBY_STATE
_CSODOTALOBBY.fields_by_name['lobby_type'].enum_type = _CSODOTALOBBY_LOBBYTYPE
_CSODOTALOBBY.fields_by_name['team_details'].message_type = _CLOBBYTEAMDETAILS
_CSODOTALOBBY.fields_by_name['game_state'].enum_type = dota__shared__enums__pb2._DOTA_GAMESTATE
_CSODOTALOBBY.fields_by_name['cm_pick'].enum_type = dota__shared__enums__pb2._DOTA_CM_PICK
_CSODOTALOBBY.fields_by_name['bot_difficulty_radiant'].enum_type = dota__shared__enums__pb2._DOTABOTDIFFICULTY
_CSODOTALOBBY.fields_by_name['game_version'].enum_type = dota__shared__enums__pb2._DOTAGAMEVERSION
_CSODOTALOBBY.fields_by_name['timed_reward_details'].message_type = _CLOBBYTIMEDREWARDDETAILS
_CSODOTALOBBY.fields_by_name['dota_tv_delay'].enum_type = _LOBBYDOTATVDELAY
_CSODOTALOBBY.fields_by_name['broadcast_channel_info'].message_type = _CLOBBYBROADCASTCHANNELINFO
_CSODOTALOBBY.fields_by_name['extra_messages'].message_type = _CSODOTALOBBY_CEXTRAMSG
_CSODOTALOBBY.fields_by_name['save_game'].message_type = dota__shared__enums__pb2._CDOTASAVEGAME
_CSODOTALOBBY.fields_by_name['match_outcome'].enum_type = dota__shared__enums__pb2._EMATCHOUTCOME
_CSODOTALOBBY.fields_by_name['active_ingame_events'].enum_type = dota__shared__enums__pb2._EEVENT
_CSODOTALOBBY.fields_by_name['partner_type'].enum_type = gcsdk__gcmessages__pb2._PARTNERACCOUNTTYPE
_CSODOTALOBBY.fields_by_name['visibility'].enum_type = dota__shared__enums__pb2._DOTALOBBYVISIBILITY
_CSODOTALOBBY.fields_by_name['league_selection_priority_choice'].enum_type = dota__shared__enums__pb2._SELECTIONPRIORITYTYPE
_CSODOTALOBBY.fields_by_name['league_non_selection_priority_choice'].enum_type = dota__shared__enums__pb2._SELECTIONPRIORITYTYPE
_CSODOTALOBBY.fields_by_name['pause_setting'].enum_type = _LOBBYDOTAPAUSESETTING
_CSODOTALOBBY.fields_by_name['bot_difficulty_dire'].enum_type = dota__shared__enums__pb2._DOTABOTDIFFICULTY
_CSODOTALOBBY_STATE.containing_type = _CSODOTALOBBY
_CSODOTALOBBY_LOBBYTYPE.containing_type = _CSODOTALOBBY
DESCRIPTOR.message_types_by_name['CSODOTAPartyMember'] = _CSODOTAPARTYMEMBER
DESCRIPTOR.message_types_by_name['CSODOTAParty'] = _CSODOTAPARTY
DESCRIPTOR.message_types_by_name['CSODOTAPartyInvite'] = _CSODOTAPARTYINVITE
DESCRIPTOR.message_types_by_name['CSODOTALobbyInvite'] = _CSODOTALOBBYINVITE
DESCRIPTOR.message_types_by_name['CMsgLeaverState'] = _CMSGLEAVERSTATE
DESCRIPTOR.message_types_by_name['CDOTALobbyMember'] = _CDOTALOBBYMEMBER
DESCRIPTOR.message_types_by_name['CLobbyTeamDetails'] = _CLOBBYTEAMDETAILS
DESCRIPTOR.message_types_by_name['CLobbyTimedRewardDetails'] = _CLOBBYTIMEDREWARDDETAILS
DESCRIPTOR.message_types_by_name['CLobbyBroadcastChannelInfo'] = _CLOBBYBROADCASTCHANNELINFO
DESCRIPTOR.message_types_by_name['CSODOTALobby'] = _CSODOTALOBBY
DESCRIPTOR.enum_types_by_name['LobbyDotaTVDelay'] = _LOBBYDOTATVDELAY
DESCRIPTOR.enum_types_by_name['LobbyDotaPauseSetting'] = _LOBBYDOTAPAUSESETTING

CSODOTAPartyMember = _reflection.GeneratedProtocolMessageType('CSODOTAPartyMember', (_message.Message,), dict(
  DESCRIPTOR = _CSODOTAPARTYMEMBER,
  __module__ = 'dota_gcmessages_common_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CSODOTAPartyMember)
  ))
_sym_db.RegisterMessage(CSODOTAPartyMember)

CSODOTAParty = _reflection.GeneratedProtocolMessageType('CSODOTAParty', (_message.Message,), dict(
  DESCRIPTOR = _CSODOTAPARTY,
  __module__ = 'dota_gcmessages_common_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CSODOTAParty)
  ))
_sym_db.RegisterMessage(CSODOTAParty)

CSODOTAPartyInvite = _reflection.GeneratedProtocolMessageType('CSODOTAPartyInvite', (_message.Message,), dict(

  PartyMember = _reflection.GeneratedProtocolMessageType('PartyMember', (_message.Message,), dict(
    DESCRIPTOR = _CSODOTAPARTYINVITE_PARTYMEMBER,
    __module__ = 'dota_gcmessages_common_match_management_pb2'
    # @@protoc_insertion_point(class_scope:CSODOTAPartyInvite.PartyMember)
    ))
  ,
  DESCRIPTOR = _CSODOTAPARTYINVITE,
  __module__ = 'dota_gcmessages_common_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CSODOTAPartyInvite)
  ))
_sym_db.RegisterMessage(CSODOTAPartyInvite)
_sym_db.RegisterMessage(CSODOTAPartyInvite.PartyMember)

CSODOTALobbyInvite = _reflection.GeneratedProtocolMessageType('CSODOTALobbyInvite', (_message.Message,), dict(

  LobbyMember = _reflection.GeneratedProtocolMessageType('LobbyMember', (_message.Message,), dict(
    DESCRIPTOR = _CSODOTALOBBYINVITE_LOBBYMEMBER,
    __module__ = 'dota_gcmessages_common_match_management_pb2'
    # @@protoc_insertion_point(class_scope:CSODOTALobbyInvite.LobbyMember)
    ))
  ,
  DESCRIPTOR = _CSODOTALOBBYINVITE,
  __module__ = 'dota_gcmessages_common_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CSODOTALobbyInvite)
  ))
_sym_db.RegisterMessage(CSODOTALobbyInvite)
_sym_db.RegisterMessage(CSODOTALobbyInvite.LobbyMember)

CMsgLeaverState = _reflection.GeneratedProtocolMessageType('CMsgLeaverState', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLEAVERSTATE,
  __module__ = 'dota_gcmessages_common_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLeaverState)
  ))
_sym_db.RegisterMessage(CMsgLeaverState)

CDOTALobbyMember = _reflection.GeneratedProtocolMessageType('CDOTALobbyMember', (_message.Message,), dict(

  CDOTALobbyMemberXPBonus = _reflection.GeneratedProtocolMessageType('CDOTALobbyMemberXPBonus', (_message.Message,), dict(
    DESCRIPTOR = _CDOTALOBBYMEMBER_CDOTALOBBYMEMBERXPBONUS,
    __module__ = 'dota_gcmessages_common_match_management_pb2'
    # @@protoc_insertion_point(class_scope:CDOTALobbyMember.CDOTALobbyMemberXPBonus)
    ))
  ,
  DESCRIPTOR = _CDOTALOBBYMEMBER,
  __module__ = 'dota_gcmessages_common_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CDOTALobbyMember)
  ))
_sym_db.RegisterMessage(CDOTALobbyMember)
_sym_db.RegisterMessage(CDOTALobbyMember.CDOTALobbyMemberXPBonus)

CLobbyTeamDetails = _reflection.GeneratedProtocolMessageType('CLobbyTeamDetails', (_message.Message,), dict(
  DESCRIPTOR = _CLOBBYTEAMDETAILS,
  __module__ = 'dota_gcmessages_common_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CLobbyTeamDetails)
  ))
_sym_db.RegisterMessage(CLobbyTeamDetails)

CLobbyTimedRewardDetails = _reflection.GeneratedProtocolMessageType('CLobbyTimedRewardDetails', (_message.Message,), dict(
  DESCRIPTOR = _CLOBBYTIMEDREWARDDETAILS,
  __module__ = 'dota_gcmessages_common_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CLobbyTimedRewardDetails)
  ))
_sym_db.RegisterMessage(CLobbyTimedRewardDetails)

CLobbyBroadcastChannelInfo = _reflection.GeneratedProtocolMessageType('CLobbyBroadcastChannelInfo', (_message.Message,), dict(
  DESCRIPTOR = _CLOBBYBROADCASTCHANNELINFO,
  __module__ = 'dota_gcmessages_common_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CLobbyBroadcastChannelInfo)
  ))
_sym_db.RegisterMessage(CLobbyBroadcastChannelInfo)

CSODOTALobby = _reflection.GeneratedProtocolMessageType('CSODOTALobby', (_message.Message,), dict(

  CExtraMsg = _reflection.GeneratedProtocolMessageType('CExtraMsg', (_message.Message,), dict(
    DESCRIPTOR = _CSODOTALOBBY_CEXTRAMSG,
    __module__ = 'dota_gcmessages_common_match_management_pb2'
    # @@protoc_insertion_point(class_scope:CSODOTALobby.CExtraMsg)
    ))
  ,
  DESCRIPTOR = _CSODOTALOBBY,
  __module__ = 'dota_gcmessages_common_match_management_pb2'
  # @@protoc_insertion_point(class_scope:CSODOTALobby)
  ))
_sym_db.RegisterMessage(CSODOTALobby)
_sym_db.RegisterMessage(CSODOTALobby.CExtraMsg)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
_CSODOTAPARTYMEMBER.fields_by_name['region_ping_codes'].has_options = True
_CSODOTAPARTYMEMBER.fields_by_name['region_ping_codes']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_CSODOTAPARTYMEMBER.fields_by_name['region_ping_times'].has_options = True
_CSODOTAPARTYMEMBER.fields_by_name['region_ping_times']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_CSODOTAPARTY.fields_by_name['party_id'].has_options = True
_CSODOTAPARTY.fields_by_name['party_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CSODOTAPARTYINVITE.fields_by_name['group_id'].has_options = True
_CSODOTAPARTYINVITE.fields_by_name['group_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CSODOTALOBBYINVITE.fields_by_name['group_id'].has_options = True
_CSODOTALOBBYINVITE.fields_by_name['group_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CDOTALOBBYMEMBER.fields_by_name['id'].has_options = True
_CDOTALOBBYMEMBER.fields_by_name['id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CSODOTALOBBY.fields_by_name['lobby_id'].has_options = True
_CSODOTALOBBY.fields_by_name['lobby_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
# @@protoc_insertion_point(module_scope)



from dota2.enums import ESOType, EGCBaseMsg, EDOTAGCMsg
from dota2.enums import DOTAJoinLobbyResult, DOTA_GC_TEAM, DOTABotDifficulty


class Lobby(object):
    EVENT_LOBBY_INVITE = 'lobby_invite'
    """When a lobby invite is received
    :param message: `CSDOTALobbyInvite <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_common_match_management.proto#L100>`_
    :type  message: proto message
    """
    EVENT_LOBBY_INVITE_REMOVED = 'lobby_invite_removed'
    """When a lobby invite is no longer valid
    :param message: `CSDOTALobbyInvite <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_common_match_management.proto#L100>`_
    :type  message: proto message
    """
    EVENT_LOBBY_NEW = 'lobby_new'
    """Entered a lobby, either by creating one or accepting an invite

    :param message: `CSODOTALobby <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_common_match_management.proto#L193>`_
    :type  message: proto message
    """
    EVENT_LOBBY_CHANGED = 'lobby_changed'
    """Anything changes to the lobby state, players, options, broadcasters...

    :param message: `CSODOTALobby <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_common_match_management.proto#L193>`_
    :type  message: proto message
    """
    EVENT_LOBBY_REMOVED = 'lobby_removed'
    """The lobby is not valid anymore, quit or kick.

    :param message: `CSODOTALobby <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_common_match_management.proto#L193>`_
    :type  message: proto message
    """
    lobby = None

    def __init__(self):
        super(Lobby, self).__init__()
        self.socache.on(('new', ESOType.CSODOTALobbyInvite), self.__handle_lobby_invite)
        self.socache.on(('removed', ESOType.CSODOTALobbyInvite), self.__handle_lobby_invite_removed)

        self.socache.on(('new', ESOType.CSODOTALobby), self.__handle_lobby_new)
        self.socache.on(('updated', ESOType.CSODOTALobby), self.__handle_lobby_changed)
        self.socache.on(('removed', ESOType.CSODOTALobby), self.__handle_lobby_removed)

    def __lobby_cleanup(self):
        self.lobby = None

    def __handle_lobby_invite(self, message):
        self.emit(self.EVENT_LOBBY_INVITE, message)

    def __handle_lobby_invite_removed(self, message):
        self.emit(self.EVENT_LOBBY_INVITE_REMOVED, message)

    def __handle_lobby_new(self, message):
        self.lobby = message
        self.emit(self.EVENT_LOBBY_NEW, message)

    def __handle_lobby_changed(self, message):
        self.lobby = message
        self.emit(self.EVENT_LOBBY_CHANGED, message)

    def __handle_lobby_removed(self, message):
        self.lobby = None
        self.emit(self.EVENT_LOBBY_REMOVED, message)

    def create_practice_lobby(self, password="", options=None):
        """
        Sends a message to the Game Coordinator requesting to create a lobby.

        :param password: password of lobby
        :type  password: :class:`str`
        :param options: options to setup the lobby with
        :type  options: :class:`dict`
        """
        return self.create_tournament_lobby(password=password, options=options)

    def create_tournament_lobby(self, password="", tournament_game_id=None, tournament_id=0, options=None):
        """
        Sends a message to the Game Coordinator requesting to create a tournament lobby.

        :param password: password of lobby
        :type  password: :class:`str`
        :param tournament_game_id: tournament game id
        :type  tournament_game_id: :class:`int`
        :param tournament_id: tournament id
        :type  tournament_id: :class:`int`
        :param options: options to setup the lobby with
        :type  options: :class:`dict`
        """
        options = {} if options is None else options
        options["pass_key"] = password

        command = {
            "lobby_details": options,
            "pass_key": password
        }
        if tournament_game_id is not None:
            command.update({
                "tournament_game": True,
                "tournament_game_id": tournament_game_id,
                "tournament_id": tournament_id
            })

        if self.verbose_debug:
            self._LOG.debug("Sending match CMsgPracticeLobbyCreate request")

        self.send(EDOTAGCMsg.EMsgGCPracticeLobbyCreate, command)

    def config_practice_lobby(self, options):
        """
        Change settings of the current lobby.

        :param options: options to change in the lobby
        :type  options: :class:`dict`
        """
        if self.lobby is None or self.lobby.leader_id != self.steam.steam_id:
            return

        options = {} if options is None else options
        options['lobby_id'] = self.lobby.lobby_id

        if self.verbose_debug:
            self._LOG.debug("Changing lobby options of lobby %s", self.lobby.lobby_id)

        self.send(EDOTAGCMsg.EMsgGCPracticeLobbySetDetails, options)

    def get_practice_lobby_list(self):
        """
        Request a list of practice lobbies.

        :return: List of `CMsgPracticeLobbyListResponseEntry <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_client_match_management.proto#L202-L226>`_
        :rtype: proto message, :class:`None`
        """
        if self.verbose_debug:
            self._LOG.debug("Requesting practice lobby list.")

        jobid = self.send_job(EDOTAGCMsg.EMsgGCPracticeLobbyList, {})
        resp = self.wait_msg(jobid, timeout=10)

        return resp.lobbies if resp else None

    def get_friend_practice_lobby_list(self):
        """
        Request a list of friend practice lobbies.

        :return: List of `CMsgPracticeLobbyListResponseEntry <https://github.com/ValvePython/dota2/blob/ca75440adca20d852b9aec3917e4387466848d5b/protobufs/dota_gcmessages_client_match_management.proto#L202-L226>`_
        :rtype: proto message, :class:`None`
        """
        if self.verbose_debug:
            self._LOG.debug("Requesting friend practice lobby list.")

        jobid = self.send_job(EDOTAGCMsg.EMsgGCFriendPracticeLobbyListRequest, {})
        resp = self.wait_msg(jobid, timeout=10)

        return resp.lobbies if resp else None

    def balanced_shuffle_lobby(self):
        """
        Balance shuffle the the lobby.
        """
        if self.lobby is None or self.lobby.leader_id != self.steam.steam_id:
            return

        if self.verbose_debug:
            self._LOG.debug("Balance shuffle the the lobby")

        self.send(EDOTAGCMsg.EMsgGCBalancedShuffleLobby, {})

    def flip_lobby_teams(self):
        """
        Flip both teams of the lobby.
        """
        if self.lobby is None or self.lobby.leader_id != self.steam.steam_id:
            return

        if self.verbose_debug:
            self._LOG.debug("Flipping teams of the lobby")

        self.send(EDOTAGCMsg.EMsgGCFlipLobbyTeams, {})

    def invite_to_lobby(self, steam_id):
        """
        Asks to invite a player to your lobby. This creates a new default lobby when you are not already in one.

        :param steam_id: steam_id
        :type  steam_id: :class:`int`
        """
        if self.lobby is None:
            return

        if self.verbose_debug:
            self._LOG.debug("Inviting %s to a lobby." % steam_id)

        self.send(EGCBaseMsg.EMsgGCInviteToLobby, {
            "steam_id": steam_id
        })

    def practice_lobby_kick(self, account_id):
        """
        Kick a player from the lobby.

        :param account_id: 32-bit steam_id of the user to kick from the lobby
        :type  account_id: :class:`int`
        """
        if self.lobby is None or self.lobby.leader_id != self.steam.steam_id:
            return

        if self.verbose_debug:
            self._LOG.debug("Kicking %s from the lobby." % account_id)

        self.send(EDOTAGCMsg.EMsgGCPracticeLobbyKick, {
            "account_id": account_id
        })

    def practice_lobby_kick_from_team(self, account_id):
        """
        Kick a player from the his current lobby team.

        :param account_id: 32-bit steam_id of the user to kick from a team
        :type  account_id: :class:`int`
        """
        if self.lobby is None or self.lobby.leader_id != self.steam.steam_id:
            return

        if self.verbose_debug or self.lobby.leader_id != self.steam.steam_id:
            self._LOG.debug("Kicking %s from his lobby team." % account_id)

        self.send(EDOTAGCMsg.EMsgGCPracticeLobbyKickFromTeam, {
            "account_id": account_id
        })

    def join_practice_lobby(self, id, password=""):
        """
        Join the target practice lobby.

        :param id: id of the lobby to join
        :type  id: :class:`int`
        :param password: password necessary to join the lobby
        :type  password: :class:`str`
        :return: Result of the join command from the GC
        :rtype: :class: `DOTAJoinLobbyResult`. `DOTAJoinLobbyResult.DOTA_JOIN_RESULT_TIMEOUT` if timeout
        """
        if self.verbose_debug:
            self._LOG.debug("Trying to join practice lobby %s using password %s" % (id, password))

        jobid = self.send_job(EDOTAGCMsg.EMsgGCPracticeLobbyJoin, {
            "lobby_id": id,
            "pass_key": password
        })
        resp = self.wait_msg(jobid, timeout=10)

        return DOTAJoinLobbyResult(resp.result) if resp else DOTAJoinLobbyResult.DOTA_JOIN_RESULT_TIMEOUT

    def leave_practice_lobby(self):
        """
        Sends a message to the Game Coordinator requesting to leave the current lobby.
        """
        if self.lobby is None:
            return

        if self.verbose_debug:
            self._LOG.debug("Sending match CMsgPracticeLobbyLeave request")

        self.send(EDOTAGCMsg.EMsgGCPracticeLobbyLeave, {})

    def abandon_current_game(self):
        """
        Abandon the current game.
        """
        if self.lobby is None:
            return

        if self.verbose_debug:
            self._LOG.debug("Abandoning current game.")

        self.send(EDOTAGCMsg.EMsgGCAbandonCurrentGame, {})

    def launch_practice_lobby(self):
        """
        Launch the current lobby into a game.
        """
        if self.lobby is None or self.lobby.leader_id != self.steam.steam_id:
            return

        if self.verbose_debug:
            self._LOG.debug("Starting current lobby.")

        self.send(EDOTAGCMsg.EMsgGCPracticeLobbyLaunch, {})

    def join_practice_lobby_team(self, slot=1, team=DOTA_GC_TEAM.PLAYER_POOL):
        """
        Join on of the lobby team at the specified slot.

        :param slot: slot to join into
        :type  slot: :class:`int`
        :param team: team to join
        :type  team: :class:`DOTA_GC_TEAM`
        """
        if self.lobby is None:
            return

        if self.verbose_debug:
            self._LOG.debug("Joining slot %s of lobby team %s." % (slot, team))

        self.send(EDOTAGCMsg.EMsgGCPracticeLobbySetTeamSlot, {
            "team": team,
            "slot": slot
        })

    def join_practice_lobby_broadcast_channel(self, channel=1):
        """
        Join a specific channel of the broadcasters.

        :param channel: channel to join into
        :type  channel: :class:`int`
        """
        if self.lobby is None:
            return

        if self.verbose_debug:
            self._LOG.debug("Joining channel %s of lobby broadcst." % channel)

        self.send(EDOTAGCMsg.EMsgGCPracticeLobbyJoinBroadcastChannel, {
            "channel": channel
        })

    def add_bot_to_practice_lobby(self, slot=1, team=DOTA_GC_TEAM.GOOD_GUYS, bot_difficulty=DOTABotDifficulty.BOT_DIFFICULTY_PASSIVE):
        """
        Add a bot in the lobby.

        :param slot: slot to join into
        :type  slot: :class:`int`
        :param team: team to join
        :type  team: :class:`.DOTA_GC_TEAM`
        :param bot_difficulty: difficulty of the bot
        :type  bot_difficulty: :class:`.DOTABotDifficulty`
        """
        if self.lobby is None or self.lobby.leader_id != self.steam.steam_id:
            return

        if self.verbose_debug:
            self._LOG.debug("Adding a bot %s in slot %s of lobby team %s." % (bot_difficulty, slot, team))

        self.send(EDOTAGCMsg.EMsgGCPracticeLobbySetTeamSlot, {
            "team": team,
            "slot": slot,
            "bot_difficulty": bot_difficulty
        })

    def respond_lobby_invite(self, id, accept=False):
        """
        Answer to a lobby invite.

        :param id: lobby_id to answer to.
        :type  id: :class:`int`
        :param accept: answer to the lobby invite
        :type  accept: :class:`bool`
        """
        if self.verbose_debug:
            self._LOG.debug("Responding to lobby invite %s, accept: %s" % (id, accept))

        self.send(EGCBaseMsg.EMsgGCLobbyInviteResponse, {
            "lobby_id": id,
            "accept": accept
        })
